# Install required packages if not already installed.

list.of.packages <- c("jmv", "psy", "psych", "lavaan", "lavaanPlot")
new.packages <- list.of.packages[!(list.of.packages %in% installed.packages()[, "Package"])]
if (length(new.packages)) install.packages(new.packages)

library(jmv)
library(psy)
library(psych)
library(lavaan)
library(lavaanPlot)

# Read the small sample and large sample data.

data1 <- read.csv("./query222.csv")
data2 <- read.csv("./query738.csv")

# Table 1

print("Table 1. Psychometric properties of the dependent variables")

rowheadings <- c("items", "participants", "mean", "SD", "alpha", "skew")

warmthframe <- data.frame(data1$goodwill_1, data1$goodwill_2, data1$goodwill_3, data1$goodwill_4, data1$goodwill_5, data1$goodwill_6, data1$trustworthiness_1, data1$trustworthiness_2, data1$trustworthiness_3, data1$trustworthiness_4, data1$trustworthiness_5, data1$trustworthiness_6)
cronbach(warmthframe)
warmthvalue <- c(cronbach(warmthframe)$number.of.items, cronbach(warmthframe)$sample.size, mean(data1$warmth), sd(data1$warmth), cronbach(warmthframe)$alpha, skew(data1$warmth))
warmthvalue

competenceframe <- data.frame(data1$competence_1, data1$competence_2, data1$competence_3, data1$competence_4, data1$competence_5, data1$competence_6)
competencevalue <- c(cronbach(competenceframe)$number.of.items, cronbach(competenceframe)$sample.size, mean(data1$competence), sd(data1$competence), cronbach(competenceframe)$alpha, skew(data1$competence))
competencevalue

humanrealismframe <- data.frame(data1$humanness_1, data1$humanness_2, data1$humanness_3, data1$humanness_4, data1$realism_1, data1$realism_2, data1$realism_3)
humanrealismvalue <- c(cronbach(humanrealismframe)$number.of.items, cronbach(humanrealismframe)$sample.size, mean(data1$humanrealism), sd(data1$humanrealism), cronbach(humanrealismframe)$alpha, skew(data1$humanrealism))
humanrealismvalue

eerinessframe <- data.frame(data1$eeriness_1, data1$eeriness_2, data1$eeriness_3, data1$eeriness_4, data1$eeriness_5, data1$eeriness_6, data1$eeriness_7)
eerinessvalue <- c(cronbach(eerinessframe)$number.of.items, cronbach(eerinessframe)$sample.size, mean(data1$eeriness), sd(data1$eeriness), cronbach(eerinessframe)$alpha, skew(data1$eeriness))
eerinessvalue
# use big data sample here
adherenceframe <- data.frame(data2$adherence_1, data2$adherence_2, data2$adherence_3, data2$adherence_4, data2$adherence_5, data2$adherence_6, data2$adherence_8)
adherencevalue <- c(cronbach(adherenceframe)$number.of.items, cronbach(adherenceframe)$sample.size, mean(data2$adherenceintention), sd(data2$adherenceintention), cronbach(adherenceframe)$alpha, skew(data2$adherenceintention))
adherencevalue

enjoymentframe <- data.frame(data2$enjoyment_1, data2$enjoyment_2, data2$enjoyment_3, data2$enjoyment_4, data2$enjoyment_5, data2$enjoyment_6, data2$enjoyment_7, data2$enjoyment_8, data2$enjoyment_9, data2$enjoyment_10, data2$enjoyment_11, data2$enjoyment_12)
enjoymentvalue <- c(cronbach(enjoymentframe)$number.of.items, cronbach(enjoymentframe)$sample.size, mean(data2$enjoyment), sd(data2$enjoyment), cronbach(enjoymentframe)$alpha, skew(data2$enjoyment))
enjoymentvalue

table1 <- data.frame(rowheadings, warmthvalue, competencevalue, humanrealismvalue, eerinessvalue, adherencevalue, enjoymentvalue)

print(table1)
readline(prompt = "Press [enter] to continue.")

# Manipulation checks

print("Results: Manipulation checks")
print("A three-way MANOVA of Character, Outcome, and Depiction on Warmth, Competence, Human Realism, and Eeriness")

mc <- jmv::mancova(
  data = data1,
  deps = c(
    "warmth",
    "competence",
    "humanrealism",
    "eeriness"
  ),
  factors = c("character", "outcome", "depiction"),
  multivar = "pillai"
)

print(mc)
readline(prompt = "Press [enter] to continue.")

# Table 2

print("Table 2. ANOVAs of Character, Outcome, and Depiction on Warmth, Competence, Human Realism, and Eeriness")

print("ANOVA on Warmth")

aw <- jmv::anova(
  data = data1,
  dep = "warmth",
  factors = c("character", "outcome", "depiction"),
  effectSize = "partEta",
  postHoc = list(
    "character"
  ),
  emMeans = list(
    NULL
  )
)

print(aw)
readline(prompt = "Press [enter] to continue.")

print("ANOVA on Competence")

ac <- jmv::anova(
  data = data1,
  dep = "competence",
  factors = c("character", "outcome", "depiction"),
  effectSize = "partEta",
  postHoc = list(
    "character", "outcome"
  ),
  emMeans = list(
    NULL
  )
)

print(ac)
readline(prompt = "Press [enter] to continue.")

print("ANOVA on Human Realism")

ah <- jmv::anova(
  data = data1,
  dep = "humanrealism",
  factors = c("character", "outcome", "depiction"),
  effectSize = "partEta",
  postHoc = list(
    "depiction"
  ),
  emMeans = list(
    NULL
  )
)

print(ah)
readline(prompt = "Press [enter] to continue.")

print("ANOVA on Eeriness")

ae <- jmv::anova(
  data = data1,
  dep = "eeriness",
  factors = c("character", "outcome", "depiction"),
  effectSize = "partEta",
  postHoc = list(
    "character"
  ),
  emMeans = list(
    NULL
  )
)

print(ae)
readline(prompt = "Press [enter] to continue.")

# Linear regression

print("Results: Regression analysis")
print("Table 3. Model coefficients for Adherence Intention")
print("Model 1")

m1 <- jmv::linReg(
  data = data1,
  dep = "adherenceintention",
  covs = c(
    "warmth",
    "competence",
    "humanrealism",
    "eeriness",
    "enjoyment"
  ),
  blocks = list(
    list(
      "warmth",
      "competence",
      "humanrealism",
      "eeriness",
      "enjoyment"
    )
  ),
  refLevels = list(),
  r = FALSE,
  r2Adj = TRUE,
  modelTest = TRUE,
  stdEst = TRUE,
  emMeans = list(
    NULL
  )
)

print(m1)
readline(prompt = "Press [enter] to continue.")

print("Model 2")

m2 <- jmv::linReg(
  data = data1,
  dep = "adherenceintention",
  covs = c(
    "warmth",
    "competence",
    "humanrealism",
    "eeriness"
  ),
  blocks = list(
    list(
      "warmth",
      "competence",
      "humanrealism",
      "eeriness"
    )
  ),
  refLevels = list(),
  r = FALSE,
  r2Adj = TRUE,
  modelTest = TRUE,
  stdEst = TRUE,
  emMeans = list(
    NULL
  )
)

print(m2)
readline(prompt = "Press [enter] to continue.")

print("Model 3")

m3 <- jmv::linReg(
  data = data1,
  dep = "adherenceintention",
  covs = c(
    "warmth",
    "competence",
    "eeriness"
  ),
  blocks = list(
    list(
      "warmth",
      "competence",
      "eeriness"
    )
  ),
  refLevels = list(),
  r = FALSE,
  r2Adj = TRUE,
  modelTest = TRUE,
  stdEst = TRUE,
  emMeans = list(
    NULL
  )
)

print(m3)
readline(prompt = "Press [enter] to continue.")

# Hypothesis Testing

print("Results: Hypothesis testing")
print("Three-way MANOVA of Character, Outcome, and Depiction on Adherence Intention and Enjoyment")

mn <- jmv::mancova(
  data = data2,
  deps = c("adherenceintention", "enjoyment"),
  factors = c("character", "outcome", "depiction"),
  multivar = "pillai"
)

print(mn)
readline(prompt = "Press [enter] to continue.")

print("Table 4: ANOVAs of Character, Outcome, and Depiction on Adherence Intention and Enjoyment")
print("Adherence Intention")

aa <- jmv::anova(
  data = data2,
  dep = "adherenceintention",
  factors = c("character", "outcome", "depiction"),
  effectSize = "partEta",
  postHoc = list(
    "character",
    "outcome",
    "depiction"
  ),
  emMeans = list(
    NULL
  )
)

print(aa)
readline(prompt = "Press [enter] to continue.")

print("Enjoyment")

ae <- jmv::anova(
  data = data2,
  dep = "enjoyment",
  factors = c("character", "outcome", "depiction"),
  effectSize = "partEta",
  postHoc = list(
    "character",
    "outcome",
    "depiction"
  ),
  emMeans = list(
    NULL
  )
)

print(ae)
readline(prompt = "Press [enter] to continue.")

# Figure 2

print("Figure 2. Means and 95% confidence intervals of Adherence Intention and Enjoyment plotted by Character and Depiction")
print("Adherence Intention")

dcoa <- jmv::anova(
  data = data2,
  dep = "adherenceintention",
  factors = c("depiction", "character"),
  emMeans = list(
    c("character", "depiction")
  ),
  emmTables = TRUE
)

print(dcoa)
readline(prompt = "Press [enter] to continue.")

print("Enjoyment")

dcoe <- jmv::anova(
  data = data2,
  dep = "enjoyment",
  factors = c("depiction", "character"),
  emMeans = list(
    c("character", "depiction")
  ),
  emmTables = TRUE
)

print(dcoe)
readline(prompt = "Press [enter] to continue.")

# Table 5

print("Table 5: Correlations for analysis of path models of Warmth")

c <- jmv::corrMatrix(
  data = data1,
  vars = c(
    "warmth",
    "eeriness",
    "enjoyment",
    "humanrealism",
    "depiction_dummy"
  )
)

print(c)
readline(prompt = "Press [enter] to continue.")

# Secondary Analysis

print("Results: Structural analysis of path models")
print("Figure 3: Path models of the indirect effect of Enjoyment of computer animation on Eeriness")
print("Table 6: Global fit statistics for path models of Eeriness (1, 2) and of Eeriness and Warmth (3, 4, 4a, 4b)")

print("Model 1")

Model1 <- '
  eeriness ~ humanrealism
  humanrealism ~ depiction
'
fit1 <- sem(Model1, data = data1)

summary(fit1, standardized = TRUE, fit.measures = TRUE)
p1 <- lavaanPlot(model = fit1, node_options = list(shape = "box", fontname = "Helvetica"), edge_options = list(fontname = "Helvetica", color = "grey"), coefs = TRUE, covs = TRUE, stars = "regress", stand = TRUE)
print(p1)
readline(prompt = "Press [enter] to continue.")

print("Model 2")

Model2 <- '
  eeriness ~ humanrealism
  humanrealism ~ enjoyment + depiction
  enjoyment ~ depiction
'
fit2 <- sem(Model2, data = data1)

summary(fit2, standardized = TRUE, fit.measures = TRUE)
p2 <- lavaanPlot(model = fit2, node_options = list(shape = "box", fontname = "Helvetica"), edge_options = list(fontname = "Helvetica", color = "grey"), coefs = TRUE, covs = TRUE, stars = "regress", stand = TRUE)
print(p2)
readline(prompt = "Press [enter] to continue.")

print("Model 3")

Model3 <- '
  warmth ~ eeriness
  eeriness ~ humanrealism
  humanrealism ~ enjoyment + depiction
  enjoyment ~ depiction
'
fit3 <- sem(Model3, data = data1)

summary(fit3, standardized = TRUE, fit.measures = TRUE)
p3 <- lavaanPlot(model = fit3, node_options = list(shape = "box", fontname = "Helvetica"), edge_options = list(fontname = "Helvetica", color = "grey"), coefs = TRUE, covs = TRUE, stars = "regress", stand = TRUE)
print(p3)
readline(prompt = "Press [enter] to continue.")

print("Model 4")

model4 <- '
  warmth ~ eeriness + enjoyment
  eeriness ~ humanrealism
  humanrealism ~ enjoyment + depiction
  enjoyment ~ depiction
'
fit4 <- sem(model4, data = data1)

summary(fit4, standardized = TRUE, fit.measures = TRUE)
p4 <- lavaanPlot(model = fit4, node_options = list(shape = "box", fontname = "Helvetica"), edge_options = list(fontname = "Helvetica", color = "grey"), coefs = TRUE, covs = TRUE, stars = "regress", stand = TRUE)
print(p4)
readline(prompt = "Press [enter] to continue.")

print("Model 4a")

model4a <- '
  eeriness ~ warmth + humanrealism
  warmth ~ enjoyment
  humanrealism ~ enjoyment + depiction
  enjoyment ~ depiction
'
fit4a <- sem(model4a, data = data1)

summary(fit4a, standardized = TRUE, fit.measures = TRUE)
p4a <- lavaanPlot(model = fit4a, node_options = list(shape = "box", fontname = "Helvetica"), edge_options = list(fontname = "Helvetica", color = "grey"), coefs = TRUE, covs = TRUE, stars = "regress", stand = TRUE)
print(p4a)
readline(prompt = "Press [enter] to continue.")

print("Model 4b")

model4b <- '
  eeriness ~ warmth + humanrealism
  warmth ~ enjoyment
  enjoyment ~ humanrealism
  enjoyment ~ depiction
  humanrealism ~ depiction
'
fit4b <- sem(model4b, data = data1)

summary(fit4b, standardized = TRUE, fit.measures = TRUE)
p4b <- lavaanPlot(model = fit4b, node_options = list(shape = "box", fontname = "Helvetica"), edge_options = list(fontname = "Helvetica", color = "grey"), coefs = TRUE, covs = TRUE, stars = "regress", stand = TRUE)
print(p4b)
print("Analysis completed.")
